@@ -638,6 +638,10 @@ class QueuedResource(proto.Message):
         state (google.cloud.tpu_v2alpha1.types.QueuedResourceState):
             Output only. State of the QueuedResource
             request.
+        reservation_name (str):
+            Name of the reservation in which the resource
+            should be provisioned. Format:
+            projects/{project}/locations/{zone}/reservations/{reservation}
     """
 
     class Tpu(proto.Message):
@@ -819,6 +823,10 @@ class QueuedResource(proto.Message):
         number=6,
         message="QueuedResourceState",
     )
+    reservation_name: str = proto.Field(
+        proto.STRING,
+        number=8,
+    )
 
 
 class QueuedResourceState(proto.Message):
